# Changelog

## [0.2.3](https://github.com/pmcgleenon/heavykeeper-py/compare/v0.2.2...v0.2.3) (2025-11-23)


### Bug Fixes

* add checkout step to Release Please workflow ([51bef4c](https://github.com/pmcgleenon/heavykeeper-py/commit/51bef4c821f0180e3f9f4d15ac630d9f016b1fe2))
* configure Release Please to update Cargo.toml and Cargo.lock ([150e970](https://github.com/pmcgleenon/heavykeeper-py/commit/150e97075530b5f8244498fe2c512ce388774533))
* correct Release Please Cargo.lock configuration ([d8dbe2b](https://github.com/pmcgleenon/heavykeeper-py/commit/d8dbe2b44de2851c247e98af219a11f15a4e3d6f))
* remove Cargo.lock from Release Please extra-files ([ad9b0b5](https://github.com/pmcgleenon/heavykeeper-py/commit/ad9b0b594b405741e4a293ca64d79d8935b10f16))
* reset Release Please manifest to v0.2.2 baseline ([1fe842d](https://github.com/pmcgleenon/heavykeeper-py/commit/1fe842d2bdef71d300f77b01dbd8fcd2b9e18a3b))
* update Release Please config for Cargo.lock handling ([3ad2554](https://github.com/pmcgleenon/heavykeeper-py/commit/3ad25542258d324e5d919e4c291c45d100af15fc))


### Dependencies

* update heavykeeper dependency to 0.6.2 ([c3eacd6](https://github.com/pmcgleenon/heavykeeper-py/commit/c3eacd6a469928e7701ca40ad87183837bad749b))


### Miscellaneous Chores

* add Release Please configuration ([55bc1cf](https://github.com/pmcgleenon/heavykeeper-py/commit/55bc1cfb99bb2a407b75f10abf617e0930e583b3))
* **main:** release 0.2.3 ([63a39f4](https://github.com/pmcgleenon/heavykeeper-py/commit/63a39f4284d21d57f1a8344afb6e5a6ada2b4fd5))
* **main:** release 0.2.3 ([ef08e14](https://github.com/pmcgleenon/heavykeeper-py/commit/ef08e14f2c7bec205e3a357ad6f004f7bb759a32))
* update Release Please workflow ([38b4469](https://github.com/pmcgleenon/heavykeeper-py/commit/38b44699b168d67adb77281daa62880d70355554))


### Build System

* **deps:** bump actions/download-artifact from 5 to 6 ([caf7d55](https://github.com/pmcgleenon/heavykeeper-py/commit/caf7d55ee0d380a311a5fed9a8b93ab254effa8a))
* **deps:** bump actions/download-artifact from 5 to 6 ([77e2c65](https://github.com/pmcgleenon/heavykeeper-py/commit/77e2c65d5ad0729e7c204250dd8b89525e3eba14))
* **deps:** bump actions/upload-artifact from 4 to 5 ([10b0c59](https://github.com/pmcgleenon/heavykeeper-py/commit/10b0c5961a17456e9489b54d69a0d77521439e1b))
* **deps:** bump actions/upload-artifact from 4 to 5 ([237949d](https://github.com/pmcgleenon/heavykeeper-py/commit/237949da1bd908b898bbef5c655309c3e3111eea))
* **deps:** bump heavykeeper from 0.6.1 to 0.6.2 ([552673c](https://github.com/pmcgleenon/heavykeeper-py/commit/552673c7aa95065eebb6b7ef98694a3db48979e2))
* **deps:** bump heavykeeper from 0.6.1 to 0.6.2 ([b5856ec](https://github.com/pmcgleenon/heavykeeper-py/commit/b5856eca9962b71febef4bbf2c9f851325ee63a9))
* **deps:** bump pyo3 from 0.26.0 to 0.27.0 ([b4a130c](https://github.com/pmcgleenon/heavykeeper-py/commit/b4a130c2dad8d7aa6b566744d8b2f251b8a252b9))
* **deps:** bump pyo3 from 0.26.0 to 0.27.0 ([3fa423a](https://github.com/pmcgleenon/heavykeeper-py/commit/3fa423a89f0569e9837a2542dfbac7bc971f90ec))
* **deps:** bump pyo3 from 0.27.0 to 0.27.1 ([5dda211](https://github.com/pmcgleenon/heavykeeper-py/commit/5dda2114be67cd5e481eaa6d73cff1de40cc1fd8))
* **deps:** bump pyo3 from 0.27.0 to 0.27.1 ([b02fa05](https://github.com/pmcgleenon/heavykeeper-py/commit/b02fa053cd2e558a17e81c90ae7bd3bb919c7335))


### Continuous Integration

* add cargo update step to workflows ([51a6190](https://github.com/pmcgleenon/heavykeeper-py/commit/51a6190966b29b1e73f47cea3bf475403757e753))
* add support for Python 3.13 and 3.14 ([1e2da81](https://github.com/pmcgleenon/heavykeeper-py/commit/1e2da81e1ca2e8d520f6223b2e72fbbcfedf63a8))
* replace deprecated macos-13 runners with macos-15 ([c76f2e9](https://github.com/pmcgleenon/heavykeeper-py/commit/c76f2e95760d062d864f18c2b402a5f49143916d))

## [0.2.3](https://github.com/pmcgleenon/heavykeeper-py/compare/v0.2.2...v0.2.3) (2025-11-23)


### Bug Fixes

* add checkout step to Release Please workflow ([51bef4c](https://github.com/pmcgleenon/heavykeeper-py/commit/51bef4c821f0180e3f9f4d15ac630d9f016b1fe2))
* configure Release Please to update Cargo.toml and Cargo.lock ([150e970](https://github.com/pmcgleenon/heavykeeper-py/commit/150e97075530b5f8244498fe2c512ce388774533))
* correct Release Please Cargo.lock configuration ([d8dbe2b](https://github.com/pmcgleenon/heavykeeper-py/commit/d8dbe2b44de2851c247e98af219a11f15a4e3d6f))
* remove Cargo.lock from Release Please extra-files ([ad9b0b5](https://github.com/pmcgleenon/heavykeeper-py/commit/ad9b0b594b405741e4a293ca64d79d8935b10f16))
* update Release Please config for Cargo.lock handling ([3ad2554](https://github.com/pmcgleenon/heavykeeper-py/commit/3ad25542258d324e5d919e4c291c45d100af15fc))


### Dependencies

* update heavykeeper dependency to 0.6.2 ([c3eacd6](https://github.com/pmcgleenon/heavykeeper-py/commit/c3eacd6a469928e7701ca40ad87183837bad749b))


### Miscellaneous Chores

* add Release Please configuration ([55bc1cf](https://github.com/pmcgleenon/heavykeeper-py/commit/55bc1cfb99bb2a407b75f10abf617e0930e583b3))


### Build System

* **deps:** bump actions/download-artifact from 5 to 6 ([caf7d55](https://github.com/pmcgleenon/heavykeeper-py/commit/caf7d55ee0d380a311a5fed9a8b93ab254effa8a))
* **deps:** bump actions/download-artifact from 5 to 6 ([77e2c65](https://github.com/pmcgleenon/heavykeeper-py/commit/77e2c65d5ad0729e7c204250dd8b89525e3eba14))
* **deps:** bump actions/upload-artifact from 4 to 5 ([10b0c59](https://github.com/pmcgleenon/heavykeeper-py/commit/10b0c5961a17456e9489b54d69a0d77521439e1b))
* **deps:** bump actions/upload-artifact from 4 to 5 ([237949d](https://github.com/pmcgleenon/heavykeeper-py/commit/237949da1bd908b898bbef5c655309c3e3111eea))
* **deps:** bump heavykeeper from 0.6.1 to 0.6.2 ([552673c](https://github.com/pmcgleenon/heavykeeper-py/commit/552673c7aa95065eebb6b7ef98694a3db48979e2))
* **deps:** bump heavykeeper from 0.6.1 to 0.6.2 ([b5856ec](https://github.com/pmcgleenon/heavykeeper-py/commit/b5856eca9962b71febef4bbf2c9f851325ee63a9))
* **deps:** bump pyo3 from 0.26.0 to 0.27.0 ([b4a130c](https://github.com/pmcgleenon/heavykeeper-py/commit/b4a130c2dad8d7aa6b566744d8b2f251b8a252b9))
* **deps:** bump pyo3 from 0.26.0 to 0.27.0 ([3fa423a](https://github.com/pmcgleenon/heavykeeper-py/commit/3fa423a89f0569e9837a2542dfbac7bc971f90ec))
* **deps:** bump pyo3 from 0.27.0 to 0.27.1 ([5dda211](https://github.com/pmcgleenon/heavykeeper-py/commit/5dda2114be67cd5e481eaa6d73cff1de40cc1fd8))
* **deps:** bump pyo3 from 0.27.0 to 0.27.1 ([b02fa05](https://github.com/pmcgleenon/heavykeeper-py/commit/b02fa053cd2e558a17e81c90ae7bd3bb919c7335))


### Continuous Integration

* add cargo update step to workflows ([51a6190](https://github.com/pmcgleenon/heavykeeper-py/commit/51a6190966b29b1e73f47cea3bf475403757e753))
* add support for Python 3.13 and 3.14 ([1e2da81](https://github.com/pmcgleenon/heavykeeper-py/commit/1e2da81e1ca2e8d520f6223b2e72fbbcfedf63a8))
* replace deprecated macos-13 runners with macos-15 ([c76f2e9](https://github.com/pmcgleenon/heavykeeper-py/commit/c76f2e95760d062d864f18c2b402a5f49143916d))

## [0.2.2](https://github.com/pmcgleenon/heavykeeper-py/compare/v0.2.1...v0.2.2) (2025-10-12)

Updated to Heavykeeper version 0.6.1


## [0.2.1](https://github.com/pmcgleenon/heavykeeper-py/compare/v0.2.0...v0.2.1) (2025-06-06)


### Documentation

* update changelog for v0.2.0 release ([3967e92](https://github.com/pmcgleenon/heavykeeper-py/commit/3967e92b90aaa8ac00c0e5c890414a13fa83cac8))

## 0.2.0 (2025-06-04)

### Features
* Manual release v0.2.0
* Improved CI/CD workflows
* Enhanced security for release process

## 0.1.0 (2025-06-04)

### Changes

* Initial release of heavykeeper
